kedro.framework.hooks.specs.DataCatalogSpecs — Kedro 0.17.6 documentation

# kedro.framework.hooks.specs.DataCatalogSpecs

class `kedro.framework.hooks.specs.` `DataCatalogSpecs`

  Namespace that defines all specifications for a data catalog’s lifecycle hooks.

  Methods

  `after_catalog_created`(catalog, conf_catalog, …) | Hooks to be invoked after a data catalog is created.

  `after_catalog_created`(catalog, conf_catalog, conf_creds, feed_dict, save_version, load_versions, run_id)

    Hooks to be invoked after a data catalog is created. It receives the `catalog` as well as all the arguments for `KedroContext._create_catalog`.

    Parameters

      - catalog (`DataCatalog`) – The catalog that was created.

      - conf_catalog (`Dict`[`str`, `Any`]) – The config from which the catalog was created.

      - conf_creds (`Dict`[`str`, `Any`]) – The credentials conf from which the catalog was created.

      - feed_dict (`Dict`[`str`, `Any`]) – The feed_dict that was added to the catalog after creation.

      - save_version (`str`) – The save_version used in `save` operations for all datasets in the catalog.

      - load_versions (`Dict`[`str`, `str`]) – The load_versions used in `load` operations for each dataset in the catalog.

      - run_id (`str`) – The id of the run for which the catalog is loaded.

    Return type

      `None`